User Guide
==========
This user guide will get you started using pyfurc even if you are an
inexperienced user. Experienced users may first want to try following
:ref:`the quickstart section on the main page<Quickstart>` instead.

Getting Started
+++++++++++++++

.. toctree::
    :maxdepth: 2

    installation_ubuntu
    tutorial

Appendix
++++++++

.. toctree::
    installation_wsl
